"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var schemaGenerator_1 = require("../schemaGenerator");
var delegateToSchema_1 = require("./delegateToSchema");
var transforms_1 = require("../transforms");
function makeTransformSchema(schema, transforms) {
    var transformedSchema = transforms_1.applySchemaTransforms(schema, transforms);
    var resolvers = createProxyingResolvers(schema, transforms, {
        query: transformedSchema.getQueryType(),
        mutation: transformedSchema.getMutationType(),
        subscription: transformedSchema.getSubscriptionType(),
    });
    schemaGenerator_1.addResolveFunctionsToSchema(transformedSchema, resolvers);
    return transformedSchema;
}
exports.default = makeTransformSchema;
function createProxyingResolvers(targetSchema, transforms, _a) {
    var query = _a.query, mutation = _a.mutation, subscription = _a.subscription;
    var resolvers = {};
    if (query) {
        Object.keys(query.getFields()).map(function (fieldName) {
            if (!resolvers.Query) {
                resolvers.Query = {};
            }
            resolvers.Query[fieldName] = createProxyingResolver(targetSchema, 'query', fieldName, transforms);
        });
    }
    if (mutation) {
        Object.keys(mutation.getFields()).map(function (fieldName) {
            if (!resolvers.Mutation) {
                resolvers.Mutation = {};
            }
            resolvers.Mutation[fieldName] = createProxyingResolver(targetSchema, 'mutation', fieldName, transforms);
        });
    }
    if (subscription) {
        Object.keys(subscription.getFields()).map(function (fieldName) {
            if (!resolvers.Subscription) {
                resolvers.Subscription = {};
            }
            resolvers.Subscription[fieldName] = createProxyingResolver(targetSchema, 'subscription', fieldName, transforms);
        });
    }
    return resolvers;
}
function createProxyingResolver(targetSchema, targetOperation, targetField, transforms) {
    return function (parent, args, context, info) {
        return delegateToSchema_1.default(targetSchema, targetOperation, targetField, {}, context, info, transforms);
    };
}
//# sourceMappingURL=makeTransformSchema.js.map